package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````(``P`!````^I<$"#0```!DL@```````#0`(``)
M`"@`'0`<``8````T````-(`$"#2`!`@@`0``(`$```4````$`````P```%0!
M``!4@00(5($$"!,````3````!`````$````!``````````"`!`@`@`0(U*L`
M`-2K```%`````!````$```#XK@``^#X%"/@^!0@@`@``?!(```8`````$```
M`@````2O```$/P4(!#\%"/@```#X````!@````0````$````:`$``&B!!`AH
M@00(1````$0````$````!````%#E=&3HG0``Z!T%".@=!0C<````W`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71D^*X`
M`/@^!0CX/@4("`$```@!```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,@``
M!````!`````!````1TY5```````"````!@```"`````$````%`````,```!'
M3E4`PT(?:=6`\/&8`*XG0YT;=?8()'XE````00````@````(`````!P0!"5`
M!((X`4`!H(8!B,`!``)+*`0I.*(R1XH$#`A!````0P``````````````````
M`$4```!'````2`````````!)````2@```$P```!-````3@```$\`````````
M40``````````````4@```%,```!6``````````````!7````60```%H```!<
M`````````%X```!@````````````````````8@```&,`````````R-6R<5GH
M[>S.WD<MH^#[2>K3[PZGW:-K+\6;MMO-XYZ'^9R!5J2;EFL)0]8Y\HL<#3J7
M"\6)!9`,%.*>B0=PTR'_Y`X+BA!7Q+F<0&I_FGRS`8MO?ZF<FV[%WQ_9<5@<
MN^.2?*Q+X\#59-1\X*<""C-BV^UZ\$IK9Z_,9D)%U>SC1\8!P^4_+/+;TQWZ
MH6Q@N8WQ#@````````````````````"N`@`````````````2````5`,`````
M````````$@```/(!`````````````!(````1```````````````@````P@,`
M````````````$@```$4#`````````````!(````9`0`````````````2````
MR0(`````````````$@```+P``````````````!(```"U`@`````````````2
M````F```````````````$@```!0!`````````````!(```!L`@``````````
M```2`````@,`````````````$@```'T"`````````````!(```!O`0``````
M```````2````$@,`````````````$@````D#`````````````!(````]`0``
M```````````2````R@``````````````$@```+D!`````````````!(````[
M`@`````````````2````Z@$`````````````$@```)D"`````````````!(`
M``"F`0`````````````2````B@(`````````````$@```+(!````````````
M`!(```!+`0`````````````2````&0,`````````````$@```"T`````````
M`````"````!-`@`````````````2````)@,`````````````$@```'@`````
M`````````!(```"G`@`````````````2````6P,`````````````$@```.,!
M`````````````!(```"G```````````````2````9`$`````````````$@``
M`(0"`````````````!(```!:`@`````````````2````"P(`````````````
M$@```)("`````````````!(```!J```````````````2````'@$`````````
M````$@```-`"`````````````!(```";`0`````````````2````^```````
M````````$@```$T#`````````````!(```"@`@`````````````2````?0$`
M````````````$@```#P``````````````"````#<```````````````2````
M6P$`````````````$@```"T#`````````````!(```"[`@`````````````2
M````4```````````````(````%("`````````````!(```#Q`@``````````
M```2````]P$`````````````$@```-X"`````````````!(````<`@``````
M```````2````8P(`````````````$@```.D"`````````````!(````W`P``
M```````````2````*@$``&"4!`@`````$@```#H$``#XW`0(!````!$`$`#P
M`P``P,L$"$$,```2``X`000``##(!`BW`0``$@`.`)D#``#DW`0(`````!(`
M#P!O`P``($$%"`0````A`!H`GP,``$#%!`@%````$@`.`"`$``"`W`0(70``
M`!(`#@"'````$)4$"``````2````"0$``#!!!0@$````$0`:`/T#```(004(
M`````!``&0#[`@``*$$%"`0````1`!H`_P,```A!!0@`````(``9`&X#```@
M004(!````"$`&@"/`P``X-P$"`(````2``X`,`0``!1!!0@$````$0`9`%8$
M``!0Q00(N`$``!(`#@#K````-$$%"`$````1`!H`;0,``"!!!0@$````$0`:
M`&@#``#PE00("@(``!(`#@!U!```\,D$"&D````2``X`L`,``&#*!`@D````
M$@`.`,L#``#@VP0(:0```!(`#@!^`P``&$$%"``````0`!H`B@,``'11!0@`
M````$``:`"P"``#\W`0(!````!$`$`"#!```$-@$",X#```2``X`"@0``(#$
M!`BQ````$@`.``,$``#ZEP0(`````!(`#@"+`0``<)($"``````2````Y`,`
M`$#'!`CG````$@`.`'<#```8004(`````!``&0#7`P``$,<$""(````2``X`
M3@0```#$!`@G````$@`.`,0!```X004($P```!$`&@!C!```D,H$""8!```2
M``X`4`0``+B1!`@`````$@`+``!L:6)P97)L+G-O+C4N,C(`7TE435]D97)E
M9VES=&5R5$U#;&]N951A8FQE`%]?9VUO;E]S=&%R=%]?`%]*=E]296=I<W1E
M<D-L87-S97,`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!097)L7W-Y<U]T
M97)M`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS
M=')U8W0`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]A=E]S:&EF=`!097)L
M7W-V7S)P=E]F;&%G<P!097)L7W-V7W-E='!V;@!03%]D;U]U;F1U;7``4&5R
M;%]N97=84U]F;&%G<P!03%]T:')?:V5Y`'!E<FQ?9G)E90!097)L7VUG7W-E
M=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E
M=&-H<'8`<&5R;%]R=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?
M879?9F5T8V@`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E
M<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y7W=R87``;&EB<'1H<F5A
M9"YS;RXP`&]P96XV-`!L<V5E:S8T`')E860`<'1H<F5A9%]G971S<&5C:69I
M8P!?7V5R<FYO7VQO8V%T:6]N`&-L;W-E`&QI8F,N<V\N-@!?24]?<W1D:6Y?
M=7-E9`!?7W)E9VES=&5R7V%T9F]R:P!E>&ET`'-T<FYC;7``7U]S=')D=7``
M8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A;&QO
M8P!M96UC:'(`9V5T<&ED`'-T<G1O:P!S=')L96X`<W1R<W1R`')M9&ER`%]?
M9G!R:6YT9E]C:&L`;65M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L>'-T870V-`!O
M<&5N9&ER`%]?>'-T870V-`!S=&1E<G(`9V5T=6ED`')E861L:6YK`&5X96-V
M<`!?7VUE;6-P>5]C:&L`<W1R8VAR`')E861D:7(V-`!?7W-P<FEN=&9?8VAK
M`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?<W1A<G1?;6%I;@!?7V5N
M=FER;VX`7V5D871A`%]?8G-S7W-T87)T`%]E;F0`7U]L:6)C7V-S=5]F:6YI
M`'!A<E]C=7)R96YT7V5X96,`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`
M<&%R7V-L96%N=7``<&%R7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A<E]M:W1M
M<&1I<@!?7V1A=&%?<W1A<G0`<&%R7V-U<G)E;G1?97AE8U]P<F]C`%]?;&EB
M8U]C<W5?:6YI=`!M>5]P87)?<&P`7V9P7VAW`'!A<E]I;FET7V5N=@!X<U]I
M;FET`'!A<E]F:6YD<')O9P!P87)?<V5T=7!?;&EB<&%T:`!P87)?96YV7V-L
M96%N`%A37TEN=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R+C(`1TQ)0D-?,BXP
M`$=,24)#7S(N,RXT`$=,24)#7S(N,RXR`$=,24)#7S(N-``````"``(``P``
M``(``@`"``(````"```````$``(``@````(``@`````````%``8``@````(`
M`@````<````"``(````"``(`!@```````@`"``,``@``````!P```````@`"
M````````````"``'`````@`(``,`"``#``(``@`'`````0`!``$``0`"``$`
M`0```````0`"``$``@`!``$``0````(``0`!``$``0`!``$``0`!``$``0``
M``$``0`!``$````!``$``0`"`-,!```0````,````!)I:0T```8`F00``!``
M```0:6D-```#`*,$`````````0`%`"("```0`````````!)I:0T```@`F00`
M`!````!T&6D)```'`*T$```0````<AEI"0``!0"Y!```$````!1I:0T```0`
MQ00``!`````0:6D-```"`*,$````````_#\%"`8>```@004(!5,``"A!!0@%
M3```,$$%"`5*```T004(!5(``#A!!0@%8P``#$`%"`<!```00`4(!P(``!1`
M!0@'`P``&$`%"`<%```<0`4(!P8``"!`!0@'!P``)$`%"`<(```H0`4(!PD`
M`"Q`!0@'7@``,$`%"`<*```T0`4(!PL``#A`!0@'#```/$`%"`<-``!`0`4(
M!PX``$1`!0@'#P``2$`%"`<0``!,0`4(!Q$``%!`!0@'$@``5$`%"`<3``!8
M0`4(!Q0``%Q`!0@'%0``8$`%"`<6``!D0`4(!Q<``&A`!0@'&```;$`%"`<9
M``!P0`4(!QH``'1`!0@'&P``>$`%"`<<``!\0`4(!QT``(!`!0@''P``A$`%
M"`<@``"(0`4(!R$``(Q`!0@'(@``D$`%"`<C``"40`4(!R0``)A`!0@')0``
MG$`%"`<F``"@0`4(!R<``*1`!0@'*```J$`%"`=!``"L0`4(!RD``+!`!0@'
M*@``M$`%"`<K``"X0`4(!RP``+Q`!0@'+0``P$`%"`<N``#$0`4(!R\``,A`
M!0@',```S$`%"`<Q``#00`4(!S(``-1`!0@'20``V$`%"`<T``#<0`4(!S4`
M`.!`!0@'-@``Y$`%"`<W``#H0`4(!SD``.Q`!0@'.@``\$`%"`<[``#T0`4(
M!SP``/A`!0@'/0``_$`%"`<^````004(!S\```1!!0@'0```4X/L".A?!@``
M@<,_K@``BX/\____A<!T!>@*!```@\0(6\,``````/\U!$`%"/\E"$`%"```
M``#_)0Q`!0AH`````.G@_____R400`4(:`@```#IT/____\E%$`%"&@0````
MZ<#_____)1A`!0AH&````.FP_____R4<0`4(:"````#IH/____\E($`%"&@H
M````Z9#_____)21`!0AH,````.F`_____R4H0`4(:#@```#I</____\E+$`%
M"&A`````Z6#_____)3!`!0AH2````.E0_____R4T0`4(:%````#I0/____\E
M.$`%"&A8````Z3#_____)3Q`!0AH8````.D@_____R5`0`4(:&@```#I$/__
M__\E1$`%"&AP````Z0#_____)4A`!0AH>````.GP_O___R5,0`4(:(````#I
MX/[___\E4$`%"&B(````Z=#^____)51`!0AHD````.G`_O___R580`4(:)@`
M``#IL/[___\E7$`%"&B@````Z:#^____)6!`!0AHJ````.F0_O___R5D0`4(
M:+````#I@/[___\E:$`%"&BX````Z7#^____)6Q`!0AHP````.E@_O___R5P
M0`4(:,@```#I4/[___\E=$`%"&C0````Z4#^____)7A`!0AHV````.DP_O__
M_R5\0`4(:.````#I(/[___\E@$`%"&CH````Z1#^____)81`!0AH\````.D`
M_O___R6(0`4(:/@```#I\/W___\EC$`%"&@``0``Z>#]____)9!`!0AH"`$`
M`.G0_?___R640`4(:!`!``#IP/W___\EF$`%"&@8`0``Z;#]____)9Q`!0AH
M(`$``.F@_?___R6@0`4(:"@!``#ID/W___\EI$`%"&@P`0``Z8#]____):A`
M!0AH.`$``.EP_?___R6L0`4(:$`!``#I8/W___\EL$`%"&A(`0``Z5#]____
M);1`!0AH4`$``.E`_?___R6X0`4(:%@!``#I,/W___\EO$`%"&A@`0``Z2#]
M____)<!`!0AH:`$``.D0_?___R7$0`4(:'`!``#I`/W___\ER$`%"&AX`0``
MZ?#\____)<Q`!0AH@`$``.G@_/___R700`4(:(@!``#IT/S___\EU$`%"&B0
M`0``Z<#\____)=A`!0AHF`$``.FP_/___R7<0`4(:*`!``#IH/S___\EX$`%
M"&BH`0``Z9#\____)>1`!0AHL`$``.F`_/___R7H0`4(:+@!``#I</S___\E
M[$`%"&C``0``Z6#\____)?!`!0AHR`$``.E0_/___R7T0`4(:-`!``#I0/S_
M__\E^$`%"&C8`0``Z3#\____)?Q`!0AHX`$``.D@_/___R4`004(:.@!``#I
M$/S___\E!$$%"&CP`0``Z0#\____)?P_!0AFD```````````C4PD!(/D\/]Q
M_%6)Y59348G+@^PPBT$$B474BT$(B4709:$4````B47D,<"-1=!0C4744%'H
MMOW__X/$#&A@E`0(:&"4!`AH$)4$".@/1@``@\00@#TT004(`'4QZ-[\__^%
MP*-P404(#X21`0``@^P,4.@H_/__6?\U,$$%".@,____@\00QH!Y!0```(/L
M#/\U,$$%".CT_O__@(@*`P```EK_-3!!!0CHX?[__X"("@,```&+`X/$$(/`
M!3W___\_#X<%`0``@^P,P>`"4.BK_/__BW74BQN#Q!"C9%$%",<%:%$%"`0`
M``"+%H/[`<=`!-O>!`C'0`S>W@0(B1"+%11!!0B)4`BZ`0```'X5C;0F````
M`(L,EHE,D`R#P@$YVG7R@^P,QT28#`````"#PP-J`%!3:##$!`C_-7!1!0CH
MB/W__X/$((7`B<-T48/L#/\U<%$%".B1^___C57@N)_=!`CHE"8``(/$$(7`
M=$2#[`S_-7!1!0CH+_O__^@:_?__@\00B=B+=>1E,S44````=62-9?196UY=
MC6'\PX/L#/\U<%$%".B0_?__@\00B</KFJ%L404(A<!T'X/L#%#H)T0``(/$
M$.NE4%!H.$$%"&A/W00(Z%'\__^-5>"X5-T$".@4)@``A<"C;%$%"`^$>O__
M_^O%Z,#Z__^#[`QJ`>C&^___,>U>B>&#Y/!05%)HX-P$"&B`W`0(459H\)4$
M".CE^___]&:09I"+'"3#9I!FD&:09I!FD&:0N!M!!0@M&$$%"(/X!G8:N```
M``"%P'0158GE@^P4:!A!!0C_T(/$$,GSPY"-="8`N!A!!0@M&$$%",'X`HG"
MP>H?`=#1^'0;N@````"%TG0258GE@^P04&@8004(_]*#Q!#)\\.-="8`C;PG
M`````(`]2T$%"`!U$U6)Y8/L".A\____Q@5+004(`<GSPV:0N``_!0B+$(72
M=07KDXUV`+H`````A=)T\E6)Y8/L%%#_TH/$$,GI=?___V:09I"055>-:#A6
M4X'L#`,``(E$)#R-A"2`````B7PD#&6+%10```")E"3\`@``,=*)[XET)`B)
MQ8UT)@"+!XM7!#';QT7\`````(/%$(/'"`_(B=:)T8E%Z(G0P>88P>`(B=HE
M``#_``GPB<:)R`^LT!C!ZA@)QHG(B10D#ZS8""4`_P``"?")1?"+!"2)1?2-
MA"0``0``.>AUH8V$).````"-E"3@`@``C78`BQB+2`2#P`@S6-`S2-0S6*`S
M2*0S6)`S2)3'0!0`````B=Z)SXG9`?&)^XD,)(GQ#ZSY'PL,)`^D\P&)7"0$
MB4@0.=!UNHM$)#R+.(MH!(MP&(GZBW@(B>F+:`R)="0(B<N+<"")3"04B=&)
M?"08BW@0B6PD'(MH%(ET)%B)UHE4)!")/"2+>!S!Y@4/K-D;B6PD!(GU,=*)
M?"0,BW@D"<V+="18`W0D>(GHB7PD7(M\)%P3?"1\B?&!P9EY@EJ)^X/3``'(
MBTPD&!':BQPDB40D((E4)"2+5"0(B=TQU8GO(<^)^HM\)`@Q^HM\)""+1"08
MBQPDBTPD$,=$)"0`````QT0D-``````!UXM4)!R)QHE\)"B)?"0@B<?!YAX/
MK-<"B?6+="0("?T#M"2`````BWPD#!.\)(0```");"0PB?"+="0$!9EY@EJ)
M^HG?@](`,>\C="04(<\S/"0S="0$B?F)\P'!BT0D(!'3BU0D)(E,)$")7"1$
MBUPD0(G&#ZS0&XM4)!3!Y@6)P8M$)!`)\0'+,?^)P8G>B5PD4`^LT`+!X1X)
MP8M$)"B)3"1`,>DAR(G"BP0D,>H#A"2(````B=$%F7F"6@'!B?#!X`6)1"0H
MB?"+;"0H#ZSX&XM4)"3'1"0L`````(E$)$@+;"1(BT0D(,=$)"0``````>F)
M3"0HB4PD8(G!P>$>#ZS0`HM4)$")S0G%BT0D4(EL)$B)TS'K(=@QT(M4)"R)
MP8M$)#`#A"20````!9EY@EH!P8M$)"C!X`6)1"0@BT0D*(ML)"`/K-`;B40D
M,`ML)#"+1"1``>F)3"0@B4PD4(GQP>$>#ZS^`HG+BXPDF````(M\)$@)\XMT
M)&")VHE<)$"!P9EY@EH!P3'ZBT0D("'6BU0D)(GU,?V)Q@'IP>8%#ZS0&XE$
M)#"+;"0PBT0D*(M4)"S'1"0T`````,=$)"P`````"?6+="1``>F)3"1@B4PD
M,(G!P>$>B?4/K-`"BY0DH````(G+"<.+1"1(B5PD0('"F7F"6HG1BU0D-`'!
M,=V)Z(ML)%`AQ8M$)#")[S'W`?G!X`6)QXM$)#`/K-`;BU0D),=$)"0`````
MB40D*`M\)"B+1"0@`?F+?"1`B4PD*(E,)%")P0^LT`*+E"2H````P>$>B<T)
MQ8'"F7F"6HEL)$B)T8GZ`?$QZB-4)&")U3']BWPD*`'IBVPD+(GXP>`%B40D
M((GX#ZSH&XML)"`)Q0'IB4PD8(E,)""+?"0PBVPD-(M$)$#'1"0T`````(GZ
MB?Z+?"1(P>(>B=.+E"2P````#ZSN`@GS@<*9>8):BW0D4(G1B=J)7"1``<$Q
M^HM$)"`AUHM4)"2)]3']B<8!Z<'F!0^LT!N+5"0LB<O'1"0L`````(E$)#"+
M1"0HBVPD,(G!"?6+="1``>O!X1X/K-`"BY0DN````(E<)#")]8E<)%")RPG#
MBT0D2('"F7F"6HE<)$")T8M4)#0!P3'=B>B+;"1@(<6+1"0PB>\Q]P'YP>`%
MB<>+1"0P#ZS0&XM4)"2)1"0H"WPD*(M$)"`!^8E,)&")3"0HB<$/K-`"BY0D
MP````,'A'HM\)$")S<=$)"0`````"<6!PIEY@EJ);"1(B=&)^@'Q,>HC5"10
MB=4Q_8M\)"@!Z8ML)"R)^,'@!8E$)"")^(M\)#`/K.@;BVPD((GZB?Z+?"1(
M"<6+1"1``>F+;"0TP>(>B=.+E"3(````B4PD4(E,)"#'1"0T``````^L[@()
M\X'"F7F"6HMT)&")T8G:B5PD0`'!,?J+1"0@(=:+5"0DB?4Q_8G&`>G!Y@4/
MK-`;BU0D+(E$)#"+;"0PBT0D*`GUBW0D0`'IB4PD,(E,)&")P<'A'HGU#ZS0
M`HN4)-````")RPG#BT0D2(E<)$"!PIEY@EJ)T0'!,=V)Z(ML)%`AQ8M$)#")
M[S'W`?G!X`6)QXM$)#"+5"0TQT0D+``````/K-`;BU0D),=$)"0`````B40D
M*`M\)"B+1"0@`?F+?"1`B4PD4(E,)"B)P0^LT`*+E"38````P>$>B<T)Q8'"
MF7F"6HEL)$B)T8GZ`?$QZB-4)&")U3']BWPD*`'IBVPD+(GXP>`%B40D((GX
MBWPD,`^LZ!N+;"0@B?J)_HM\)$@)Q8M$)$`!Z8ML)#3!XAZ)TXN4).````")
M3"0@B4PD8`^L[@()\X'"F7F"6HMT)%")T8G:B5PD0`'!,?J+1"0@(=:+5"0D
MB?4Q_8G&`>G!Y@4/K-`;B<N)1"0PBVPD,`GU`>N)7"10B5PD,(M$)"B+5"0L
MBW0D0,=$)#0`````QT0D+`````")P<'A'HGU#ZS0`HG+BXPDZ````(M4)#0)
MPXM$)$B)7"1`@<&9>8):`<$QW8GHBVPD8"'%BT0D,(GO,?<!^<'@!8G'BT0D
M,`^LT!N+5"0DQT0D)`````")1"0H"WPD*(M$)"`!^8M\)$")3"0HB4PD8(G!
MP>$>B<V+C"3P````#ZS0`HGZ"<6!P9EY@EH!\3'J(U0D4(EL)$B)U3']BWPD
M*`'IBVPD+(GXP>`%B40D((GXBWPD,`^LZ!N+;"0@B?J)_@G%`>F+;"0TP>(>
MB=.+E"3X````B4PD4(E,)""+1"1`#ZSN`HM\)$C'1"0T``````GS@<*9>8):
MBW0D8(G1B=J)7"1``<$Q^HM$)"`AUHM4)"2)]3']B<8!Z<'F!0^LT!N+5"0L
MQT0D+`````")1"0PBVPD,(M$)"@)]8MT)$`!Z8E,)#")3"1@B<'!X1Z)]0^L
MT`*+E"0``0``B<L)PXM$)$B)7"1`@<*9>8):B=&+5"0T`<$QW8GHBVPD4"'%
MBT0D,(GO,?<!^<'@!8G'BT0D,`^LT!N+5"0DB40D*`M\)"B+1"0@`?F+?"1`
MB4PD4(E,)"B)P0^LT`*+E"0(`0``P>$>B<T)Q8'"F7F"6HEL)$B)T8GZ`?$Q
MZB-4)&")U3']BWPD*,=$)"0``````>F+;"0LB?C!X`6)1"0@B?B+?"0P#ZSH
M&XML)"")^HG^"<6+1"1``>F+;"0TP>(>B=.+E"00`0``B4PD8(E,)""+?"1@
M#ZSN`HML)$C'1"0T``````GS@<*9>8):B=&+5"1(B5PD0`'!BT0D4#':(="+
M5"0D,<6+1"0@`>F)RXG&#ZS0&XM4)"S!Y@6)1"0PBT0D*(ML)#")P0GU`>O!
MX1Z+;"1`#ZS0`HE<)#")7"10B<N+E"08`0``"<.+1"1(@<*AZ]EN`=`QW8M4
M)#0Q[XGY`<&+1"0PP>`%B<>+1"0P#ZS0&XE$)"B+;"0HBT0D((M4)"2)7"1(
MQT0D+``````)_<=$)"0``````>F)3"1@B4PD*(G!P>$>BWPD*`^LT`*)S8N4
M)"`!```)Q8M$)$");"1`@<*AZ]EN`=`QZXML)%`QW8GIBVPD+`'!B?C!X`6)
M1"0@B?B+?"0P#ZSH&XML)"")^HG^BWPD8`G%BT0D2`'IBVPD-,'B'HE,)"")
M3"10#ZSN`HG5BY0D*`$```GUB6PD2('"H>O9;@'0,VPD0(M4)"0Q[XGY`<&+
M1"0@B<8/K-`;P>8%BU0D+(E$)#"+;"0PBT0D*`GU`>DQ_XG.B4PD8(G!P>$>
M#ZS0`HG+"<.)7"0PBY0D,`$``(N,)#0!``"+1"1`BVPD2('"H>O9;H/1`(G+
MB=$QT@'($=HS;"0PB40D*(E4)"R+5"10B?"+7"0PQT0D+``````QZHG1`TPD
M*,'@!8E$)"B)\(ML)"@/K/@;BU0D)(E$)$`+;"1`BT0D(`'IB4PD*(E,)%")
MP<'A'@^LT`*)S8N4)#@!```)Q8M$)$B);"1`@<*AZ]EN`=`QZXML)&"+5"0L
M,=V)Z0'!BT0D*,'@!8E$)""+1"0HBVPD(`^LT!N)\HE$)$@+;"1(`>G!XAZ)
M3"1@B=6)3"0@BY0D0`$``(M$)#`/K/X"BWPD4,=$)"0`````"?6!PJ'KV6['
M1"0T``````'0B6PD2#-L)$"+5"0D,>^)^8M\)&`!P8M$)"")RXG&#ZS0&XM4
M)"S!Y@7'1"0L`````(E$)#"+1"0HBVPD,(G!"?4!Z\'A'HML)$@/K-`"B5PD
M,(E<)%")RXN4)$@!```)PXM$)$"!PJ'KV6X!T#'=BU0D-#'OB?D!P8M$)##!
MX`6)QXM$)#`/K-`;BU0D)(E$)"@+?"0HBT0D(`'YB4PD8(E,)"B)P<'A'@^L
MT`*)S8N4)%`!```)Q8M$)$B)7"1(B6PD0(M\)"B!PJ'KV6['1"0D``````'0
M,>N+;"10,=V)Z8ML)"P!P8GXP>`%B40D((GXBWPD,`^LZ!N+;"0@B?J)_HM\
M)&`)Q8M$)$@!Z8ML)#3!XAZ)3"10B4PD(`^L[@*)U8N4)%@!```)]8EL)$B!
MPJ'KV6X!T#-L)$"+5"0D,>^)^0'!BT0D((G&#ZS0&\'F!8M4)"R)1"0PBVPD
M,(M$)"@)]0'I,?^+;"1(B<Z)3"1@B<'!X1X/K-`"BY0D8`$``(G+BXPD9`$`
M``G#BT0D0(E<)#"!PJ'KV6Z#T0")RXG1,=(!R!':,VPD,(E$)"B)5"0LBU0D
M4(GP,>J)T0-,)"C!X`6)1"0HB?"+;"0H#ZSX&XM4)"2+7"0PB40D0`ML)$"+
M1"0@QT0D+`````#'1"0D``````'IB4PD*(E,)%")P<'A'@^LT`*)S8N4)&@!
M```)Q8M$)$B);"1`@<*AZ]EN`=`QZXML)&"+5"0L,=V)Z0'!BT0D*,'@!8E$
M)""+1"0HBVPD(`^LT!N)\HE$)$@+;"1(BT0D,`'IP>(>B=6+E"1P`0``B4PD
M(`^L_@*+?"10B4PD8`GU@<*AZ]EN`=");"1(,VPD0(M4)"0Q[XGY`<&+1"0@
MB<N)Q@^LT!O!Y@6)1"0PBT0D*(ML)#"+5"0LBWPD8,=$)#0`````B<''1"0L
M``````GU`>O!X1Z+;"1(#ZS0`HE<)%")7"0PB<N+E"1X`0``"<.+1"1`@<*A
MZ]EN`=`QW8M4)#0Q[XGY`<&+1"0PP>`%B<>+1"0P#ZS0&XM4)"3'1"0D````
M`(E$)"@+?"0HBT0D(`'YB4PD*(E,)&")P<'A'HM\)"@/K-`"B<V+E"2``0``
M"<6+1"1(B5PD2(EL)$"!PJ'KV6X!T#'KBVPD4#'=B>F+;"0L`<&)^,'@!8E$
M)"")^`^LZ!N+;"0@"<4!Z8E,)%")3"0@BWPD,(ML)#2+1"1(B?J)_HM\)&#!
MXAX/K.X"B=6+E"2(`0``"?6);"1(@<*AZ]EN`=`S;"1`BU0D)#'OB?D!P8M$
M)"")Q@^LT!O!Y@6+5"0LB40D,(ML)#"+1"0H"?4!Z3'_BVPD2(G.B4PD8(G!
MP>$>#ZS0`HN4))`!``")RXN,))0!```)PXM$)$")7"0P@<*AZ]EN@]$`B<N)
MT3'2`<@1VC-L)#")1"0HB50D+(M4)%")\,=$)"P`````,>J)T0-,)"C!X`6)
M1"0HB?"+;"0H#ZSX&XE$)$`+;"1``>F)3"10B4PD*(M$)""+5"0DBUPD,,=$
M)"0`````QT0D-`````")P<'A'@^LT`*)S8N4))@!```)Q8M$)$B);"1`@<*A
MZ]EN`=`QZXML)&"+5"0L,=V)Z0'!BT0D*,'@!8E$)""+1"0HBVPD(`^LT!N)
M\HE$)$@+;"1(BT0D,`'IP>(>B=6+E"2@`0``B4PD(`^L_@*+?"10B4PD8`GU
M@<*AZ]EN`=");"1(,VPD0(M4)"0Q[XGY`<&+1"0@B<N)Q@^LT!N+5"0LP>8%
MB40D,(M$)"B+;"0PB<$)]0'KP>$>#ZS0`HE<)%")7"0PB<N+E"2H`0``"<.+
M1"1`BVPD2(M\)&#'1"0L`````(E<)&"!PJ'KV6X!T#'=BU0D-#'OB?D!P8M$
M)##!X`6)QXM$)#`/K-`;BU0D),=$)"0`````B40D*`M\)"B+1"0@`?F+?"10
MB4PD0(E,)"B)P<'A'@^LT`*)S8N4)+`!``")V0G%BT0D2(GN@<*AZ]ENB?.)
M="1H`=`QZ8ML)"PQSXM4)#2)^8M\)"@!P8GXP>`%B40D((GX#ZSH&XML)"")
M1"1("VPD2(M$)#`!Z8G'B4PD2(E,)"")P0^LUP+!X1Z+1"1`B?*)S0G],?\)
MZR'JB6PD0"'8B<$)T8G.BXPDN`$``(N<)+P!``"+1"1@@<'<O!N/@],`,=(!
MR(GQ$=J)^P'!BT0D((M\)"P1TXM4)"2)3"0PB5PD-,=$)#0`````B<;'1"0L
M``````^LT!O!Y@6)P0GQBW0D*(G(BTPD,`'!BT0D2(E,)%")3"0PB?'!X1X/
MK/X"B<\)]XMT)$")^XGZB7PD2(M\)"0)\R'R(=B)P8M$)&@)T8N4),`!``")
MSHGS@<+<O!N/`="+5"0T`<.+1"0PB<8/K-`;P>8%B40D*(ML)"B+1"10"?6+
M="0@`>N)7"0HB5PD8(GQP>$>#ZS^`HM\)$B)RPGSB=J)^XGYB50D4`G3(=$A
MV(G%BT0D0`G-BXPDR`$``('!W+P;CP'(B>D!P8M$)"B+5"0LBWPD-,=$)"0`
M````QT0D-`````")Q@^LT!O!Y@6+5"10"<:+1"1@`?&+="0PB4PD:(E,)"")
MTXGQP>$>#ZS^`HG-BWPD+,=$)"P`````"?4)ZR'JB6PD0"'8B<&+1"1("=&+
ME"30`0``B<Z)\X'"W+P;CP'0BU0D)`'#BT0D((G&#ZS0&\'F!8E$)#"+;"0P
MBT0D:`GUBW0D*`'KB5PD,(E<)&")\8M<)$`/K/X"P>$>B<^+C"38`0``"?>)
M^HE\)$@)VB'0B?J)Q8M$)%`AV@G5@<'<O!N/BU0D-`'(B>D!P8M$)#")Q@^L
MT!O!Y@6)1"0HBVPD*`GU`>F)3"1HB4PD*(MT)""+?"0DBT0D8,=$)"0`````
MB?'!X1X/K/X"BWPD2(G+BXPDX`$```GSB=J)^XE4)%`)TR'8B?N+?"0TB<6+
M1"1`(=,)W8'!W+P;CXM4)"R)ZP'(`<.+1"0HB<8/K-`;P>8%BU0D4`G&BT0D
M:`'SBW0D,(E<)&")7"0@BYPD[`$``(GQP>$>#ZS^`HG-B=$Q_PGU">DAZHEL
M)$`AR(G!BT0D2`G1B<Z+C"3H`0``@<'<O!N/@],`,=(!R(GQ$=J)^P'!BT0D
M((M\)"P1TXM4)"2)3"0PB5PD-(M<)$")QL=$)#0`````#ZS0&\'F!8G!"?&+
M="0HB<B+3"0P`<&+1"1@B4PD:(E,)#")\<'A'@^L_@*)SPGWB?J)?"1(QT0D
M+``````)VB'0B?J+?"0D(=J)P8M$)%`)T8N4)/`!``#'1"0D`````(G.B?.!
MPMR\&X\!T(M4)#0!PXM$)#")Q@^LT!O!Y@6)1"0HBVPD*(M$)&@)]8MT)"`!
MZXE<)&")7"0HB?'!X1X/K/X"BWPD2(G+"?.)VHG[B?F)5"10"=,AT8M4)"PA
MV(M\)#2)Q8M$)$`)S8N,)/@!``"!P=R\&X\!R(GI`<&+1"0HB<8/K-`;P>8%
MBU0D4`G&BT0D8`'QBW0D,(E,)"")3"1HB=.)\<'A'@^L_@*)S0GU">LAZHEL
M)$`AV(G!BT0D2`G1BY0D``(``(G.B?.!PMR\&X\!T(M4)"0!PXM$)"")Q@^L
MT!O!Y@6)1"0PBVPD,`GU`>N)7"1@BW0D*(M\)"R)7"0PBUPD0(M$)&B)\<=$
M)#0`````QT0D+``````/K/X"P>$>B<^+C"0(`@``"?>)^HE\)$@)VB'0B?J+
M?"0DB<6+1"10(=H)U8'!W+P;CXM4)#3'1"0D``````'(B>D!P8M$)#")Q@^L
MT!O!Y@6)1"0HBVPD*(M$)&`)]8MT)"`!Z8E,)&B)3"0HB?'!X1X/K/X"BWPD
M2(G+BXPD$`(```GSB=J)^XE4)%`)TR'8B?N+?"0TB<6+1"1`(=,)W8'!W+P;
MCXM4)"P!R(GI`<&+1"0HB<N)Q@^LT!O!Y@6+5"10"<:+1"1H`?.+="0PB5PD
M8(E<)"")\<'A'@^L_@*)S8G1,?\)]0GI(>J);"1`(<B+G"0<`@``B<&+1"1(
M"=&)SHN,)!@"``"!P=R\&X^#TP`QT@'(B?$1VHG[`<&+1"0@BWPD+!'3BU0D
M)(E,)#")7"0TBUPD0(G&QT0D-`````#'1"0L``````^LT!O!Y@6)P0GQBW0D
M*(G(BTPD,`'!BT0D8(E,)&B)3"0PB?'!X1X/K/X"B<\)]XGZB7PD2`G:(=")
M^HM\)"0AVHG!BT0D4`G1BY0D(`(``(G.B?.!PMR\&X\!T(M4)#0!PXM$)#")
MQ@^LT!O!Y@6)1"0HBVPD*(M$)&@)]8MT)"`!ZXE<)&")7"0HB?'!X1X/K/X"
MBWPD2(G+"?.)VHG[B?F)5"10"=,AT2'8B<6+1"1`"<V+C"0H`@``@<'<O!N/
M`<B)Z0'!BT0D*(M4)"R+?"0TQT0D)`````#'1"0T`````(G&#ZS0&\'F!8M4
M)%`)QHM$)&`!\8MT)#")3"1HB4PD((G3B?'!X1X/K/X"B<V+?"0L"?4)ZR'J
MB6PD0"'8B<&+1"1("=&+E"0P`@``B<Z)\X'"W+P;CP'0BU0D)`'#BT0D((G&
M#ZS0&\'F!8E$)#"+;"0PBT0D:`GUBW0D*`'KB5PD,(E<)&")\8M<)$`/K/X"
MP>$>B<^+C"0X`@``"?>)^HE\)$@)VB'0B?J)Q8M$)%`AV@G5@<'<O!N/BU0D
M-`'(B>D!P8M$)#")Q@^LT!O!Y@6)1"0HBVPD*`GU`>F)3"1HB4PD*,=$)"P`
M````BW0D((M\)"2+1"1@QT0D)`````")\<'A'@^L_@*+?"1(B<N+C"1``@``
M"?.)VHG[B50D4`G3(=B)^XM\)#2)Q8M$)$`ATPG=@<'<O!N/BU0D+`'(B>D!
MP8M$)"B)RXG&#ZS0&\'F!8M4)%`)QHM$)&@!\XMT)#")7"1@B5PD((N<)$P"
M``")\<'A'@^L_@*)S8G1,?\)]0GI(>J);"1`(<B)P8M$)$@)T8G.BXPD2`(`
M`('!W+P;CX/3`#'2`<B)\1':B?L!P8M$)""+?"0L$=.+5"0DB4PD,(E<)#3'
M1"0T`````(G&#ZS0&\'F!8G!"?&+="0HB<B+3"0P`<&+1"1@B4PD:(E,)#")
M\<'A'@^L_@*)RPGSBW0D0(G?B=J)7"1(BUPD2,=$)"P`````"?<A\B'XBWPD
M)(G!BT0D4`G1BY0D4`(``(G.B?&!PMR\&X\!T(M4)#0!P8M$)#")Q@^LT!O!
MY@6+E"18`@``B40D*(ML)"B+1"1`"?6+="0@`>F+;"1HB4PD4(E,)"B)\<'A
M'@^L_@*)SPGW@<+6P6+*`=`Q^XM4)"PQW8E\)$")Z0'!BT0D*(G&#ZS0&\'F
M!8M4)#0)QHM$)#`!\3'_B<Z)3"1@B<'!X1X/K-`"B<V+E"1@`@``"<6+1"1(
MB6PD,(ML)$"!PM;!8LH!T#-L)#`S;"10B>D!P8GPP>`%B40D((GPBVPD(`^L
M^!N)1"1("VPD2`'IB4PD4(E,)""+1"0HBU0D+,=$)"0`````QT0D+`````")
MP<'A'@^LT`*)RXN4)&@"```)PXM$)$")W8E<)$"+7"0P@<+6P6+*`="+5"0D
M,>N+;"1@,=V+G"1P`@``B>D!P8M$)"#!X`6)1"0HBT0D((ML)"@/K-`;B?*)
M1"1("VPD2(M$)#`!Z<'B'@^L_@*)U8E,)"B)3"1@"?6!P];!8LJ+5"0LB>^+
M;"1``=B)?"1(,?V)[HML)%`Q]8GI`<&+1"0HB<N)Q@^LT!O!Y@6+5"0D"<:+
M1"0@`?,Q_XE<)%")WHG!P>$>#ZS0`HG-BY0D>`(```G%BT0D0(EL)#"+;"1(
M@<+6P6+*`=`S;"0PBU0D+#-L)&#'1"0D`````,=$)"P`````B>D!P8G8P>`%
MB40D((G8BVPD(`^L^!N)1"1`"VPD0(M$)"@!Z8E,)"")3"1@B<'!X1X/K-`"
MB<N+E"2``@``"<.+1"1(B=V)7"1`BUPD,('"UL%BR@'0BU0D)#'KBVPD4#'=
MBYPDB`(``(GI`<&+1"0@P>`%B40D*(M$)""+;"0H#ZS0&XGRB40D2`ML)$B+
M1"0P`>G!XAX/K/X"B=6)3"0HB4PD2`GU@</6P6+*B>^+;"1``=B)?"0P,?V)
M[HML)&`Q]8GI`<&+1"0HBU0D+(M<)#")Q@^LT!O!Y@6+5"0DQT0D)``````)
MQHM$)"`!\3'_B<Z)3"10B<'!X1X/K-`"B<V+E"20`@``"<6+1"1`B6PD0('"
MUL%BR@'0,>N+;"1(BU0D+#'=B>D!P8GPP>`%B40D((GPBVPD(`^L^!N)1"1(
M"VPD2(M$)"@!Z8E,)"")3"1@B<'!X1X/K-`"B<V+E"28`@``"<6+1"0PB6PD
M2('"UL%BR@'0,VPD0(M4)"0S;"10B>D!P8M$)"#!X`6)1"0HBT0D((ML)"@/
MK-`;B?*)1"0P"VPD,`'IB?V)]P^L[P+!XAZ)3"10B4PD*(GXQT0D+`````")
MUXN<)*`"```)QXML)$B+1"1`BU0D+(E\)$"!P];!8LH!V#']B>Z+;"1@,?6)
MZ0'!BT0D*(G+B<8/K-`;P>8%BU0D),=$)"0`````"<:+1"0@`?,Q_XE<)&")
MWHG!P>$>#ZS0`HG-BY0DJ`(```G%BT0D2(EL)#"+;"1`@<+6P6+*`=`S;"0P
MBU0D+#-L)%")Z0'!B=C!X`6)1"0@B=B+;"0@#ZSX&XE$)$@+;"1(BT0D*`'I
MB4PD((E,)%")P<'A'@^LT`*)RXN4)+`"```)PXM$)$")W8E<)$"+7"0P@<+6
MP6+*`=`QZXML)&`QW8GI`<&+1"0@P>`%B40D*(M$)""+5"0DBVPD*(N<)+@"
M``#'1"0L``````^LT!N)\HE$)$@+;"1(BT0D,`'IP>(>#ZS^`HG5B4PD8(E,
M)"@)]8'#UL%BRHM4)"R)[XML)$`!V(E\)$@Q_8GNBVPD4#'UB>D!P8M$)"B)
MQ@^LT!O!Y@6+5"0D"<:+1"0@`?$Q_XG.B4PD4(G!P>$>#ZS0`HN4),`"``")
MS8N,),0"```)Q8M$)$");"0PBVPD2('"UL%BRH/1`(G+B=$QT@'($=HS;"0P
M,=LS;"1@B>D!P8GP$=/!X`4QTHE$)"")\(ML)"`/K/@;B40D0`ML)$`!Z1'3
MB<J)5"1`B5PD1(E4)"#'1"0D`````(M$)"B+5"0LQT0D+`````")P<'A'@^L
MT`*+E"3(`@``B<N+C"3,`@``"<.+1"1(B=V!PM;!8LJ);"1(@]$`B<N)T3'2
M`<@1VHM<)#`QZXML)%`QW3';B>D!P8M$)"`1TXM4)"3!X`6)1"0HBT0D((ML
M)"@/K-`;,=*)1"10"VPD4(M$)#`!Z1'3B?*)3"0H#ZS^`L'B'HE<)&2+G"30
M`@``B=6)3"1@"?6+M"34`@``@</6P6+*B>^+;"1(B=F)?"10@]8`,=(!R!'R
M,?TQVXGNBVPD0#'UB>D!P8M$)"@1TXM4)"R)Q@^LT!O!Y@4QT@G&B?")WHG+
M`<.+1"0@$=:+5"0DB5PD:(ET)&PQ_XG>B<'!X1X/K-`"B<T)Q8EL)$"+E"38
M`@``BT0D2(ML)%#'1"0T`````,=$)"0`````@<+6P6+*`=`S;"1`BU0D+#-L
M)&")Z0'!B=C!X`6)1"0@B=B+;"0@#ZSX&XE$)#`+;"0PBT0D*`'IB4PD,(E,
M)$B)P<'A'@^LT`*+E"3@`@``B<N+C"3D`@``"<.+1"10B=V!PM;!8LJ);"0H
M@]$`B<N)T3'2`<@1VHM<)$`QZXML)&@QW3';B>D!P8M$)#`1TXM4)#3!X`6)
M1"0@BT0D,(ML)"`/K-`;,=*)1"10"VPD4`'I$=.)RHE4)%")7"14B50D((N<
M).@"``")\HM$)$#!XAZ+;"0H#ZS^`HG7BU0D)`GW@</6P6+*`=@Q_8E\)$")
M[HML)$@Q]8GI`<&+1"0@B<8/K-`;P>8%BU0D-`G&B?`!R#'_B<:+1"0PB<'!
MX1X/K-`"B<V+5"0@BTPD)`G%BT0D*(EL)&`/I-$>P>(>B50D,(E,)#2+5"0@
MBTPD)`^LR@+!Z0*)3"0DBXPD\`(``(E4)"")^H'!UL%BR@'(BTPD0#'IBVPD
M4#'-B>D!P8GPP>`%B40D*(GPBVPD*`^L^!L/I/(%B40D2`ML)$B)5"0LB?K!
MZAN)5"1,B>@!R(G!`TPD$(M$)#R)P\=`!`````")"(M$)!B+;"0PQT,,````
M`,=#%`````#'0QP``````?`+;"0@QT,D`````(E#"(GH`P0DB4,0BT0D8`-$
M)`B)0QB+1"1``T0D6(E#((N$)/P"``!E,P44````=0N!Q`P#``!;7E]=P^C-
MU/__C;8`````C;PG`````(7`#X2;````55=64X/L'(L-($$%"(7)B4PD"'15
M#[8(A,ET7(#Y/717B<.#PP$/M@N$R70%@/D]=?$IPXM,)`B+*87M="R)5"0,
MB<:)SV:0@^P$4U95Z!77__^#Q!"%P'4'@'P=`#UT'X/'!(LOA>UUWH/$'#'`
M6UY?7<.-="8`,=OKN(UT)@")^BM4)`B+1"0,P?H"B1"#Q!R-1!T!6UY?7<,Q
MP,.-=@"-O"<`````4XG#@^P89:$4````B40D##'`C50D"(G8Z#/___^%P'0Z
MC;0F`````(M4)`BA($$%"(T$D(M0!(72B1!TU8UV`(/`!(M0!(72B1!U](U4
M)`B)V.CY_O__A<!US8M$)`QE,P44````=06#Q!A;P^B>T___C;0F`````(V\
M)P````!55XG'5E.)TX/L.&6A%````(E$)"@QP#'`@#H]#Y3``<-3Z*G4__^#
MQ!")Q8GXC50D&.B9_O__A<`/A`$!``"#[`R)QE#HAM3__X/$$#G%#X;3````
MBT0D&(T,A0`````/M@>$P`^$BP$``#P]#X2#`0``B?CK#HGVC;PG`````(#Z
M/70*@\`!#[80A-)U\2GXC40H`H/L#(LU($$%"%`!SNC*T___@\00A<")!@^$
M5@$``*$@004(BU0D&(U/`8L4D`^V!SP]B`)T(83`=0WK&XVT)@`````\/700
M@\$!#[9!_X/"`83`B`)U[,8"/3'`C;0F``````^V#`.(3`(!@\`!A,EU\3'`
MBWPD'&4S/10````/A?D```"#Q"Q;7E]=PXVV`````(/#`0^V0_^#Q@&$P(A&
M_W7OZ\R0C70F`(L5($$%"(LRA?8/A*T````QP.L&C70F`(GPC7`!BPRRA<EU
M](T$A0P```"+#6!1!0B%R70S@^P(4%+HX=+__X/$$(7`HR!!!0AT?HT,M0``
M``#'1+`$`````(ET)!CIO?[__Y"-="8`B50D"(/L#,<%8%$%"`$```!0Z+'2
M__^#Q!"%P'1#C0RU`````(/L!%&+5"00B4PD%%*)1"044.@LT?__BT0D&(/$
M$(M,)`RC($$%".N<,<#IE/[__[@(````,?;I8O___[C_____Z?;^___H>-'_
M_Y"-M"8`````55=64XG&@>R,````9:$4````B40D?#'`A?9T!8`^`'4?BT0D
M?&4S!10````/A1\!``"!Q(P```!;7E]=PXUV`(/L#%;H-]3__X/$$(7`B<=T
MSXVV`````(/L#%?HG]/__X/$$(7`B<,/A+H```"`>Q,N#X2(````@^P,C6L3
M5N@LTO__B2PDB40D'.@@TO__BTPD'(U$`0*)!"3HL-'__XG#6%I55F@`W00(
M:O]J`5/HV]/__X/$'(U$)"!04VH#Z&O3__^#Q!"#^/]T$(M$)"PE`/```#T`
M0```=&N#[`Q3Z*K0__^#Q!"#[`Q3Z`[0__^#Q!#I7O___XVV``````^V0Q2$
MP`^$3/___SPN#X5D____@'L5``^$.O___^E5____D(UT)@"#[`Q7Z#_3__^)
M-"3H!]#__X/$$.G@_O__C;0F`````(G8Z+'^___KF.@:T/__C78`C;PG````
M`%.)PX/L%/\U,$$%".C/TO__@\0,!3@!``!04VH#Z,[2__^#Q!"%P'0'@\0(
M,<!;PX/L#/\U,$$%".BBTO__BX!(`0``@\00)0#P```]`$```'0C@^P,_S4P
M004(Z'_2__^+@$@!``"#Q!`E`/```#T`H```=;.#[`AJ`E/HO]'__X/$$(7`
M#Y3`@\0(#[;`6\/K#9"0D)"0D)"0D)"0D)!55XG'5E.)U8'L(!```&6A%```
M`(F$)!`0```QP&C_#P``C70D%%9H!MT$".B/S___@\00A<!^8(U8_X!\'`P`
M=$Z)PX/L!%-J+U;H\-#__X/$$(7`=$&#[`S_-3!!!0CHV]'__U-65U#H<M'_
M_X/$((N$)`P0``!E,P44````=36!Q!P0``!;7E]=PXUT)@"%VW6PC70F`(/L
M#/\U,$$%".B:T?__@\0,55=0Z!_/__^#Q!#KN^BUSO__D(UT)@"#[!C_-3!!
M!0CH<M'__V@(WP0(:'"2!`AH%=T$"%#H#=#__X/$+,.)]HV\)P````"#[!C_
M-3!!!0CH0M'__XD$).BZ____6/\U,$$%".@NT?__6EEJ`&C5W@0(:-7>!`AH
M$-@$"&@QW00(4.A@T/__@\0LPXVV`````(V_`````%=64X'L$"```&6A%```
M`(F$)`P@```QP.C#SO__@^P(:!'=!`A0:$;=!`AH`1```&H!C5PD)E/H%-'_
M_X/$((7`>&6#[`1H`!```(V\)!,0``!74^@GSO__@\00A<")QGA&C4`!@^P,
M4.BBSO__@\00A<")PW0Q@^P$5E=0Z$[-___&!#,`@\00B=B+E"0,(```93,5
M%````'41@<00(```6UY?PXUV`#'`Z]_H?\W__^L-D)"0D)"0D)"0D)"0D.D[
M____C70F`(V\)P````!55U93@>PL$```BYPD0!```(U4)!B+O"1$$```9:$4
M````B80D'!```#'`N%3=!`CH:_C__X/L"(G&:B]3Z#[.__^#Q!"%P'0MB=JX
M7=T$".A[^?__B=B+E"0<$```93,5%`````^%2`$``('$+!```%M>7UW#@^P,
M4^@ASO__6EF)1"04:&K=!`A7Z!#/__^#Q!")Q8M$)`R-?"0<@\`!B40D#(UT
M)@"%[72=@'T``+A2W00(#T3HA?9T%8/L"%56Z.K+__^#Q!"%P`^$F@```(/L
M#%7HQLW__X/$$(!\!?\O=1.-="8`@^@!@'P%_R_&1`4``'3Q`T0D##W_#P``
M#X]#____@^P$4VALW00(56B0W@0(:``0``!J`5?H7L___X/$%/\U,$$%".@`
MS___@\0,!3@!``!05VH#Z-_.__^#Q!"%P'4C@^P,_S4P004(Z-K.__^+@$@!
M``"#Q!`E`/```#T`@```=!F#[`AH:MT$"&H`Z";.__^#Q!")Q>DD____@^P(
M:@%7Z`'.__^#Q!"%P'75B?JX7=T$".@N^/__@^P,5^A5S?__@\00Z:3^___H
MJ,O__Y"-M"8`````BT0D!`^V"(3)=!6-4`%FD(#Y+P^V"@]$PH/"`83)=?#S
MPXVT)@````"-O"<`````4X/L&(M<)""%VW1$#[83A-)T/8A4)`^#[`Q3Z)#,
M__^-1`/_@\00#[94)`\YPW(/ZTJ-M@````"#Z`$YPW1!@#@O=/3K+XUV`(V\
M)P````"#[`QJ`NCVR___@\00A<!T?[HN````9HD0@\086\-FD(`X+W0P@^@!
M.<-R]#G#=26`^B]TR\=$)"!LW00(@\086^EZS/__C78`C;PG`````(`X+W4'
M@^@!.<-R]"G8C5`"@?H`$```=R>#P`%H`!```%!3:&!!!0CHH\S__X/$$+A@
M004(@\086\.-M@````"#Q!@QP%O#B?:-O"<`````5U:#[#1EH10```")1"0L
M,<"AY-X$"(E$)`JAZ-X$"(E$)`ZA[-X$"(E$)!*A\-X$"(E$)!:A]-X$"(E$
M)!JA^-X$"(E$)!ZA_-X$"(E$)"*A`-\$"(E$)"8/MP4$WP0(9HE$)"JX;MT$
M".@!]O__N'?=!`CH]_7__[A_W00(Z.WU__^XB-T$".CC]?__N(_=!`CHV?7_
M_[B?W00(Z,_U__^X5-T$".C%]?__N*O=!`CHN_7__[BUW00(Z+'U__^XO]T$
M".BG]?__N%W=!`CHG?7__[C)W00(Z)/U__^XTMT$".B)]?__C50D!+C=W00(
MZ,OT__^%P'0,B<*XM=T$".CK]?__C50D!+CNW00(Z*WT__^%P'0,B<*X`-X$
M".C-]?__C50D!+@+W@0(Z(_T__^%P'0SB<*X5-T$".BO]?__NC?>!`BXC]T$
M".B@]?__BT0D+&4S!10```!U58/$-%Y?PY"-="8`C50D!+@;W@0(Z$KT__^%
MP'06B<*XJ]T$".AJ]?__Z[F0C;0F`````(UT)!N_+-X$"+D*````\Z9UGXU4
M)"6XJ]T$".A`]?__ZX_HR<C__XGVC;PG`````(/L'&6A%````(E$)`PQP*$0
M004(@_C_=!>+3"0,93,-%````'4^@\0<PXVV`````(U4)`BXJ]T$".C"\___
MA<!T'@^V$(#Z,`^5P(32#Y7"#[;2(="C$$$%".N]C70F`#'`Z_'H5\C__XVT
M)@````"#[`SH6,C__X/L#%#HK\?__X/$$(7`=`B+`(/$#,-FD#'`Z_:-M@``
M``"-OP````!55[]#W@0(5E.[.=X$"(/L3(ML)&#'1"0@0]X$"(UT)"AEH10`
M``")1"0\,<#'1"0D.=X$",=$)"A&W@0(QT0D+#S>!`C'1"0P0=X$",=$)#13
MW@0(QT0D.`````#K(Y"#[`A54(E$)!CH\L;__X/$$(7`=$N%VW0JBP:)WX/&
M!(G#C50D'(GXZ-/R__^%P'0%@#@`=<J)ZHGXZ/'S__^%VW76BT0D/&4S!10`
M``!U<8/$3%M>7UW#D(VT)@````"#[`Q5Z)?(__^+3"08B40D'(D,)(E,)!CH
M@\C__XM4)!R-1`("B00DZ!/(__^#Q`R+3"0,46AJW00(56B0W@0(:O]J`5")
M1"0HZ#+*__^#Q""+5"0(B?CH=//__^E4____Z/K&__^-=@"-O"<`````55=6
M4X'L+($``(N$)$"!``"-5"0LQT0D,&K>!`C'1"0T4MT$",=$)#@`````QT0D
M2`#>!`C'1"1,^=T$"(E$)!#'1"10;]X$"&6A%````(F$)!R!```QP+A4W00(
MQT0D5!;>!`C'1"18=]X$",=$)%P`````QT0D/%[>!`C'1"1`>]X$",=$)$0`
M````Z)[Q__^%P'0)@#@`#X7Y`P``Z/S]__^%P(G##X0+!```@^P,4^AYQ___
MC40``8/$$(/L#%#H"<?__X/$$(`[`(G&B<=T*9"-="8`#[8#@^P,@\,!4&B$
MW@0(:O]J`5>#QP+H',G__X/$((`[`'7<C7PD3+@`W@0(ZQ.)]HV\)P````"#
MQP2+1_R%P'0VC50D+.@-\?__A<")PW3G@#@`=.+HK?7__X7`=-F#[`Q3Z%#'
M__^#Q!"%P(G%=5F-M"8`````BUPD,(7;=$B`.P"_`0```'46ZSR-="8`BUR\
M,(7;=#"#QP&`.P!T*(G8Z&'U__^%P'3E@^P,4^@$Q___@\00A<!TU8G%ZPN)
M]HV\)P`````Q[8/L#(GS5>B#QO__@\00BPN#PP2-D?_^_O[WT2'*@>*`@("`
M=.F)U\'O$/?"@(````]$UXU[`HG1#T3?`-&#VP.#[`PI\XV<`P0$``!3Z-S%
M__^)1"0<5HG&:(G>!`AH;-T$"%5HCMX$"&K_:@%0Z/O'__^#Q"AHP`$``%;H
M7<;__X/$$(/X_W1U@^P,_S4P004(Z(?'__^#Q`P%.`$``%#_="04:@/H@\?_
M_X/$$(7`='2#[`S_="08BT0D(/\P:%#?!`AJ`?\U*$$%".@=Q___@\0@,<"+
MC"0<@0``93,-%`````^%L`D``('$+($``%M>7UW#B?:-O"<`````Z`O&__^+
M`(/X$0^$>____X/L"%#_="08BT0D(/\P:!3?!`CKH8UV`(/L#/\U,$$%".CJ
MQO__BX!(`0``@\00)0#P```]`$````^%9?___X/L#/\U,$$%".C#QO__B[!0
M`0``Z/C#__^#Q!`YQ@^%0?___X/L#/\U,$$%".B?QO__BX!(`0``@\00)?\!
M```]P`$```^%&O___X/L#%/HC<3__XU4)#R)Q;@\W@0(Z-WN__^#Q!"%P`^$
ML@$``(/L#%#H*<7__UM>4(M$)!S_,.@;]O__@\00A<")PP^$C@$``(/L#%/H
MI<3__X/$$(/X`WXMC70#_+^7W@0(N04```#SIG4;@_@$#X0M!P``@'P#^R\/
MA"('``"-M"8`````Z&OZ__^%P'4:@^P(:@!3Z'S$__^)1"0H@\00A<`/A3@!
M``"Z-]X$"+BKW00(,=OH;.___^BGP___:-7>!`A0:&S=!`B+="085FBPW@0(
M:O]J`57H^,7__X/$(.LWC78`Z(O$__^#.!%U0.AQP___@\,!@^P,:-7>!`A3
M4&ALW00(5FB^W@0(:O]J`57HO\7__X/$,(/L"&C``0``5>@>Q/__@\00@_C_
M=+:#[`S_="08Z`K"__^)ZKA4W00(Z-[N__^)+"3H1OK__X/$$(GHZ>3]__^-
M="8`@^P,4(E$)!SH*_K__XM$)!R)!"3HW\/__X/$$.F__?__O@$```"X7MX$
M".L.C78`BT2T/(/&`87`="F-5"0LZ%3M__^%P'3H@#@`=..#[`Q0Z*+#__^#
MQ!"%P'33B</ILOO__[@-````NV/>!`CIL_O__Y"-="8`BT0D$(L8Z6?^__]J
M`FK_:NZ+="0D5NAEPO__@\0,:@:-A"0D`0``4%;H$L'__X/$$("\)!P!````
M=0Z`O"0=`0``0P^$2`8``&H`:@!J`/]T)"3H*,+__\=$)'`!(T5GQT0D=```
M``#'1"1XB:O-[\=$)'P`````QX0D@````/[<NIC'A"2$`````````,>$)(@`
M``!V5#(0QX0DC`````````#'A"20````\.'2P\>$))0`````````QX0DF```
M``````#'A"2<`````````,>$)*``````````QX0DI`````````#'A"3H````
M`````(/$$(EL)!R0C;0F`````(/L!&@`@```C80D)`$``%#_="0DZ"?`__^#
MQ!"%P(G##XX#`@``B[0DB````(N\)(P```")V)G!X`.)7"00B50D%`'P@_\`
M#X?#`0``.<8/A[L!``"+M"20````B[PDE````(M4)!2)A"2(````BT0D$,>$
M)(P`````````#ZS0'<'J'0'&BX0DV````!'7B;0DD````(F\))0```"%P`^$
M6P$``+I`````C8PDF````"G".=.)U@].\X/L!`'(5HV,)"0!``!14.BRO___
MBX0DZ`````'PB80DZ````(/$$(/X0`^%%O___XV$)!P!```I\XTL,(U$)&#H
M(<;__Y"#^S\/C@8$``"#ZT")W\'O!HUW`<'F!@'NC;0F`````(M%`(/%0(F$
M))@```"+1<2)A"2<````BT7(B80DH````(M%S(F$)*0```"+1=")A"2H````
MBT74B80DK````(M%V(F$)+````"+1=R)A"2T````BT7@B80DN````(M%Y(F$
M)+P```"+1>B)A"3`````BT7LB80DQ````(M%\(F$),@```"+1?2)A"3,````
MBT7XB80DT````(M%_(F$)-0```"-1"1@Z%3%__\Y[@^%3/___\'G!BG[:D13
M5HV$)*0```!0Z/:___^)G"3H````@\00Z0?^__^-M"8`````C:PD'`$``.GT
M_O__C70F`(NT))````"+O"24````@\8!@]<`Z3K^__^+;"0<@^P,_W0D).B7
MP?__BX0DH````(N<))@```"+M"2<````BY0DI````(E$)"")V`^L\`.)5"0D
M@^`_C5`!QH0$J````("#Q!"#^C@/CYD"``"X.````(V,))@````IT`'*@_@$
M#X._`@``A<!T"Z@"Q@(`#X5[`P``BU0D%(M$)!"-O"3S````B)PDUP````^L
MT!B+5"04B(0DT````(M$)!`/K-`0BU0D%(B$)-$```"+1"00#ZS0"(B$)-(`
M```/MD0D$(B$)-,```")V`^L\!B(A"34````B=@/K/`0B(0DU0```(G8#ZSP
M"(B$)-8```"-1"1@Z/C#__^+3"1@BUPD9(G.B(PDX@````^LWAB)\(G.#ZS>
M$(B$)-\```")\HG.BTPD:`^LW@B(E"3@````B?.)SHB,).8```"(G"3A````
MBUPD;`^LWAB)\HG.#ZS>$(B4).,```")\HG.BTPD<`^LW@B(E"3D````B?.)
MSHB,).H```"(G"3E````BUPD=`^LWAB)\HG.#ZS>$(B4).<```")\HG.BTPD
M>`^LW@B(E"3H````B?.)SHB,).X```"(G"3I````BUPD?`^LWAB)\HG.#ZS>
M$(B4).L```")\HG.BXPD@`````^LW@B(E"3L````B?.)SHB,)/(```"(G"3M
M````BYPDA`````^LWAB)\HG.#ZS>$(B4).\```")\HG.#ZS>"(B4)/````")
M\XVT).````"(G"3Q````C9PD&P$``.D)````C78`#[8&@\8!@^P,#[;`4&B$
MW@0(:O]J`5>#QP+H<;___X/$(#G[==K&A"0;`0```&C5W@0(C80D]P```%!H
M;-T$"/]T)!AHH=X$"&K_:@%5Z#V___^#Q"#IC_G__XM$)!"+4`2%T@^$UOC_
M_X/L#%*)5"0@Z#F]__^#Q!"#^`,/AKWX__^+5"00OYS>!`BY!0```(UT`OSS
MI@]$VNFA^/__B>[IP_S__XV,))@```"X0`````'1*=")PG0-,<#&!`$`@\`!
M.=!R]8U$)&"-O"28````Z-G!__^Y#@```#'`\ZOI4/W__XU*!,<"`````,=$
M`OP`````@^'\*<H!PH/B_(/Z!`^"+/W__X/B_#'`QP0!`````(/`!#G0<O+I
M%/W__X"\)!X!``!!#X6J^?__@+PD'P$``$,/A9SY__^`O"0@`0``2`^%COG_
M_X"\)"$!``!%#X6`^?__:@)J_VK&BW0D)%;HI[O__X/$#&HIC80D)`$``%!6
MZ%2Z__]HU=X$"(V$)#`!``!0:&S=!`C_="0H:*'>!`AJ_VH!5>COO?__@\0P
MZ4'X__^-M"8`````,?]FB7P"_NEY_/__Z*^Z___K#9"0D)"0D)"0D)"0D)!5
M5U93@^PH9:$4````B40D&#'`_S4P004(Z%*]__^-5"08QD!E`;B/W00(Z+#E
M__^#Q!"%P'0)@#@Q#X10`@``Z-OO__^#[`S_-3!!!0CH';W__VH+:@%HS]X$
M"%#H+KO__X/$((7`#X2S````@SUH404(`8M`#(MX&`^.H````#'VNP$```#K
M,8VT)@````"+10R#[`A0H611!0C_-)CH3+G__X/$$(7`=66A:%$%"(/#`8/&
M`3G8?EN#[`S_-3!!!0CHJ+S__VH`5E=0Z!Z\__^#Q""%P'0WBRB+10@E``0@
M`#T`!```=*:#[`S_-3!!!0CH>+S__VH":@!54.@-NO__@\0@ZXN0C;0F````
M`*%H404(C5#_.?(/A#`!``"#[`S_-3!!!0CH0KS__VH#:@%HU-X$"%#H4[K_
M_X/$((7`B<-T-(M`#(/L#(LP_S4P004(Z!>\__^#Q`QHUMX$"%90Z)BY__^+
M0PR#Q!"+&/9#"D`/A1`"``"#[`S_-3!!!0CHZ+O__VH#:@%HV]T$"%#H^;G_
M_X/$((7`B<9T.8U4)`BX7=T$".@RY/__A<")PP^$:`$``(M&#(/L#(LX_S4P
M004(Z*6[__^#Q`Q35U#H*KG__X/$$(/L#/\U,$$%".B)N___C50D&,9`90"X
M5-T$".CGX___@\00A<")PZ-L404(#X25````@^P(:,`!``!0Z!>Z__^-4`&#
MQ!"#^@%V"8/X$0^%C@$``(M$)`QE,P44````#X5X`0``@\0<6UY?7<.-=@"-
MO"<`````@_@!#X['_O__NP$```!FD(/L#/\U,$$%"(/#`>C_NO__7EU74.C6
MM___@\00.1UH404(?]OIEO[__XVV`````(!X`0`/A*O]___IH?W__Y"#[`S_
M-611!0CH`O'__X/$$(7`HVQ1!0@/A.L```"+1@R+/611!0B+&(M#""4`!"``
M/0`$```/A8T```"+0PR#[`A74.CWM___B<>+1@R#Q!"+&(M#""4`!"``/0`$
M``!U28M##%=0H611!0C_,&C(WP0(Z/BX__^0C;0F`````*%D404(@^P,BSB+
M1@R+&/\U,$$%".@VNO__B?J)V.CMY___@\00Z8[^__^#[`S_-3!!!0CH%[K_
M_VH":@!34.BLM___@\0@ZYR#[`S_-3!!!0CH^;G__VH":@!34.B.M___@\0@
MZ57___^#[`S_-3!!!0CHV+G__UI94U#H[[C__X/$$.G1_?__@^P,:*3?!`CH
M6KC__^CEMO__4*%D404(4_\P:/#?!`CH0KC__V:05E.#[!"+="0<5NA1Z___
M#[80@\00B<.$TG05C4`!9I"`^B\/MA`/1-B#P`&$TG7PZ-OM__^%]G0>A<!T
M&H`^`'05@^P(:(G>!`A3Z,"U__^#Q!`YV'0&@\0$6U[#@\0$B?!;7NGWY/__
M9I!FD&:0D%/HRKO__X'#JF,``(/L"/^S#`$``/]T)!S_="0<_W0D'.C*MO__
M@\086\-FD&:0D%57,?]64^B5N___@<-U8P``@^P,BVPD((VS_/[__^@5M?__
MC8/X_O__*<;!_@*%]G0CC;8`````@^P$_W0D+/]T)"Q5_Y2[^/[__X/'`8/$
M$#GW=>.#Q`Q;7E]=PXUV`//#``!3@^P(Z#.[__^!PQ-C``"#Q`A;PP,````!
M``(`)7,O)7,`+W!R;V,O<V5L9B]E>&4`1'EN84QO861E<CHZ8F]O=%]$>6YA
M3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`"]P<F]C+R5I+R5S`"X`4$%2
M7U1%35``4$%27U!23T=.04U%`#H`+P!015),-4Q)0@!015),3$E"`%!%4DPU
M3U!4`%!%4DQ)3P!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,
M14%.`%!!4E]$14)51P!005)?0T%#2$4`4$%27T%21T,`4$%27T%21U9?,`!0
M05)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`
M4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0`Q
M`$Q)0E!!5$@`1%E,1%],24)205)97U!!5$@`4TA,24)?4$%42`!54T52`%-9
M4U1%30`O=&UP`%1%35!$25(`5$U0`%5315).04U%`"4P,G@`<&%R+0`E<R5S
M)7,E<P!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E
M<R5S=&5M<"TE=2TE=25S`$%21U8`&`!P97)L`"UE`"TM`````%]?14Y67U!!
M4E]#3$5!3E]?("`@("`@("`@("`@("`@`````'!E<FQX<VDN8P```"5S.B!C
M<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R
M<FYO/25I*0H``"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A
M9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N
M*0H``%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y`````"5S.B!E
M>&5C=71I;VX@;V8@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@8W)E871I
M;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE
M<G)N;STE:2D*`````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@
M)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE
M;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE
M+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q
M=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U
M:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ
M9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN
M("(D<&%R7W1E;7`B?2D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H
M("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D
M<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R
M)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T
M;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P
M9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["G!R:6YT
M("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D
M;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=
M.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE
M"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PIC:&UO9"`P-S`P+"1T
M;7`M/F9I;&5N86UE.PIM>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO
M9&5V+VYU;&P@,CXF,2`F)SL*8VQO<V4@)'1M<#L*<WES=&5M*"1C;60I.PIO
M=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@
M8VQE86YU<#H@*0HN("1T;7`M/F9I;&5N86UE*3L*?0I]('T*0D5'24X@>PI)
M;G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ
M4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PII9B`H97AI<W1S
M("1%3E9[4$%27T%21U9?,'T@86YD("1%3E9[4$%27T%21U9?,'T@*2!["D!!
M4D=6(#T@;6%P("1%3E9[(E!!4E]!4D=67R1?(GTL("@Q("XN("1%3E9[4$%2
M7T%21T-]("T@,2D["B0P(#T@)$5.5GM005)?05)'5E\P?3L*?0IE;'-E('L*
M9F]R("AK97ES("5%3E8I('L*9&5L971E("1%3E9[)%]](&EF("]>4$%27T%2
M1U9?+SL*?0I]"FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5#
M;VYF:6<@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G
M.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\
M3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H
M)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R
M;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D
M871A7W!O<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P
M96X@7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PIB:6YM;V1E*%]&2"D[
M"FUY("1B=68["FUY("1S:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D;V9F<V5T
M(#T@-3$R.PIM>2`D:61X(#T@+3$["G=H:6QE("@Q*0I["B1O9F9S970@/2`D
M<VEZ92!I9B`D;V9F<V5T(#X@)'-I>F4["G-E96L@7T9(+"`M)&]F9G-E="P@
M,B!O<B!D:64@<7%;<V5E:R!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A73L*
M;7D@)&YR96%D(#T@<F5A9"!?1D@L("1B=68L("1O9F9S970["F1I92!Q<5MR
M96%D(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=('5N;&5S<R`D;G)E860@
M/3T@)&]F9G-E=#L*)&ED>"`](')I;F1E>"@D8G5F+"`B7&Y005(N<&U<;B(I
M.PIL87-T(&EF("1I9'@@/CT@,"!\?"`D;V9F<V5T(#T]("1S:7IE('Q\("1O
M9F9S970@/B`Q,C@@*B`Q,#(T.PHD;V9F<V5T("H](#(["GT*;&%S="!U;FQE
M<W,@)&ED>"`^/2`P.PHD;V9F<V5T("T]("1I9'@@+2`T.PIS965K(%]&2"P@
M+21O9F9S970L(#(["G)E860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@+21O
M9F9S970@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*<F5A9"!?1D@L("1B=68L
M(#0["B1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PIM>2`E<F5Q=6ER95]L
M:7-T.PIW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L
M(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U
M;&QN86UE(#T@)&)U9CL*;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN
M86UE(BXN+BDI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<
M9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT
M*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(
M+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD[
M"FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX
M?&%L*20O:2D@>PIM>2`H)&]U="P@)&9I;&5N86UE*2`](%]T96UP9FEL92@D
M97AT+"`D8W)C*3L*:68@*"1O=70I('L*8FEN;6]D92@D;W5T*3L*<')I;G0@
M)&]U="`D8G5F.PIC;&]S92`D;W5T.PIC:&UO9"`P-S4U+"`D9FEL96YA;64[
M"GT*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N
M86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L
M;&YA;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N
M9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2`B
M)$5.5GM005)?5$5-4'TO)&)A<V5N86UE)&5X="(["F]U=',H(E-(3$E".B`D
M9FEL96YA;65<;B(I.PIO<&5N(&UY("1O=70L("<^)RP@)&9I;&5N86UE(&]R
M(&1I92`D(3L*8FEN;6]D92@D;W5T*3L*<')I;G0@)&]U="`D8G5F.PIC;&]S
M92`D;W5T.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD
M4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^
M("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR
M96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D
M<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R
M("$D;6]D=6QE.PIM>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES
M='LD;6]D=6QE?2!\?"!D;R!["FUY("1K97D["F9O<F5A8V@@*&ME>7,@)7)E
M<75I<F5?;&ES="D@>PIN97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*)&ME
M>2`]("1?.R!L87-T.PI]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF
M(&1E9FEN960H)&ME>2D["GT@;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@
M(B]L;V%D97(O)&9I;&5N86UE+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%
M04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)
M3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D[
M"G!R:6YT("1F:"`D9FEL96YA;64M/GMB=69].PIS965K*"1F:"P@,"P@,"D[
M"G)E='5R;B`D9F@["GT*96QS92!["FUY("@D;W5T+"`D;F%M92D@/2!?=&5M
M<&9I;&4H)RYP;2<L("1F:6QE;F%M92T^>V-R8WTI.PII9B`H)&]U="D@>PIB
M:6YM;V1E*"1O=70I.PIP<FEN="`D;W5T("1F:6QE;F%M92T^>V)U9GT["F-L
M;W-E("1O=70["GT*;W!E;B!M>2`D9F@L("<\)RP@)&YA;64@;W(@9&EE("0A
M.PIB:6YM;V1E*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P
M:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I
M.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I
M<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z
M.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4[
M"G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI
M<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M
M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI
M('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U
M;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*
M9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S
M<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&
M2"D@+2`T.PI]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L
M;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%
M?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE
M;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S
M=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S
M:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II
M("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R
M"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@
M)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5]
M(#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I
M;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@
M/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q
M(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@
M97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@
M>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@
M>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@
M)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG
M.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H
M)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA8
M6#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4)RD@
M>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C
M;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=]
M.PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T
M.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]
M*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?
M=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I
M.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["D%R8VAI=F4Z.EII<#HZ
M<V5T0VAU;FM3:7IE*#$R."HQ,#(T*3L*;W!E;B!M>2`D9F@L("<\)RP@)'!A
M<B!O<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PIB:6YM;V1E*"1F
M:"D["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI:
M:7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R
M*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@(E)E860@)R1P
M87(G(&5R<F]R.B`D(2(["GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD
M(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE
M=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD
M;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*;&]C86P@)"\@
M/2!<-#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(%!!4BP@)SPG+"`D<&%R
M(&]R(&1I92`B)"$Z("1P87(B.PIB:6YM;V1E*%!!4BD["F1I92`B)'!A<B!I
M<R!N;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T
M(CL*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE
M=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=2
M3TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@
M)"$["F)I;FUO9&4H)&9H*3L*)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@
M7"1D871A7W!O<R`Z('5N9&5F.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E
M<B`]('-C86QA<B`\7T9(/CL*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD
M("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^
M87!P;'DH7"1L;V%D97(L("0P*0I]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K
M97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A
M;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`]
M(")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")0
M05)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I
M8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@
M;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD["B0O
M(#T@=6YD968["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR
M97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`]('-O<G0@>PIL96YG=&@H)&(I
M(#P]/B!L96YG=&@H)&$I"GT@9W)E<"!["B$O0E-$4$%.+PI](&=R97`@>PHH
M)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[
M87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB
M97AP?2D["GT@0$E.0SL*;7D@)69I;&5S.PHO7E\\*"XK*20O(&%N9"`M92`D
M,2!A;F0@)&9I;&5S>R0Q?2LK(&9O<B!K97ES("4Z.CL*)&9I;&5S>R1??2LK
M(&9O<B!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF
M:6=[;&EB7V5X='T["FUY("5W<FET=&5N.PIF;W)E86-H("AS;W)T(&ME>7,@
M)69I;&5S*2!["FUY("@D;F%M92P@)&9I;&4I.PIF;W)E86-H(&UY("1D:7(@
M*$!I;F,I('L*:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M7WTI('L*)&9I;&4@/2`D7SL*;&%S=#L*?0IE;'-I9B`H+UXH7%$D9&ER7$5<
M+R@N*EM>0V-=*2E<6B]I*2!["B@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD[
M"FQA<W0["GT*96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA
M*2!["FEF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q
M?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*96QS
M:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D
M,2(L("0Q*3L*;&%S=#L*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M
M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I
M;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*;W5T<R@@:F]I
M;B`B(BP*<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE
M?2`Z("1F:6QE+`IQ<2@B+BXN*0HI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D
M9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["F]P
M96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z
M("0A(CL*8FEN;6]D92A&24Q%*3L*)&-O;G1E;G0@/2`\1DE,13X["F-L;W-E
M($9)3$4["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O
M;G1E;G0L("1F:6QE*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M
M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O
M;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]
M"F]U=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B1F:"T^<')I;G0H(D9)
M3$4B*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI
M*3L*)&9H+3YP<FEN="AS<')I;G1F*`HB)3`X>"\E<R(L($%R8VAI=F4Z.EII
M<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64**2D["B1F:"T^<')I
M;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*)&9H+3YP<FEN="@D
M8V]N=&5N="D["GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF
M("1Z:7`["B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T
M,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U
M="DI6SE=*2!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(
M03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I
M9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q
M=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA
M7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@
M,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N
M(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1O=70L(")B(BD@:68@*"1C
M='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U
M="(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S
M92@D9F@I.PI]"GT*)&-A8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG
M97-T(#H@)&UT:6UE.PI]"B1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L
M96YG=&@@)&-A8VAE7VYA;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD
M9F@M/G!R:6YT*"1C86-H95]N86UE*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@
M)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B1F:"T^<')I;G0H(EQN
M4$%2+G!M7&XB*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI
M=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P
M<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN
M86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H
M:79E.CI::7`["GT*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PIM>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W.PHD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@
M)W(G*2!O<B!D:64@(B0A.B`D0"(["B1Z:7`M/G)E861&<F]M1FEL94AA;F1L
M92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R
M(&1I92`B)"$Z("1`(CL*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!
M4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]("$D14Y6
M>U!!4E]$14)51WT["F]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%3E9[
M4$%27U1%35!](BDI.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C
M('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M
M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I
M<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64[
M"FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_
M.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF
M:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M
M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D
M14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N
M86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2![
M"F]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR
M96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["GT@96QS92!["F]U=',H
M<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I
M*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PIC
M:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*
M?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@
M/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@
M6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN
M<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[
M4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I
M.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@
M/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D[
M"G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H
M*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*
M?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@
M1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*
M<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`[
M"G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@
M17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C
M;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*
M<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z
M.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ
M6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@4$%2.PIR97%U
M:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!
M4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T
M8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E
M($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER
M92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ
M:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#
M87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L
M24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S
M971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@
M)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR
M971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W
M*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@
M0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A
M=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM
M>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E
M9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I
M('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E
M9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*
M)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G
M4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER
M(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U
M<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PII9B`H(21%3E9[4$%2
M7T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI
M('L*;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M92D["G-E96L@)&9H+"`M
M,3@L(#(["G-Y<W)E860@)&9H+"!M>2`D8G5F+"`V.PII9B`H)&)U9B!E<2`B
M7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@,CL*<WES<F5A9"`D9F@L("1B
M=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP9&ER("X]("(D0V]N9FEG
M>U]D96QI;7UC86-H92TB("X@)&)U9CL*?0IE;'-E('L*;7D@)&-T>"`](&5V
M86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I
M('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(
M03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E
M<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG
M97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V97)S:6]N(&5Q
M("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C='@M/F%D
M9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@
M*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1P<F]G;F%M92(I*2!["F)I;FUO
M9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*
M)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@
M/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64@*3L*?0IC;&]S92@D9F@I.PI]
M"F5L<V4@>PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O
M;F9I9WM?9&5L:6U]=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M
M<&1I<CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP
M(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^
M("\H+BLI+SL*?0IS=6(@7W1E;7!F:6QE('L*;7D@*"1E>'0L("1C<F,I(#T@
M0%\["FUY("@D9F@L("1F:6QE;F%M92D["B1F:6QE;F%M92`]("(D<&%R7W1E
M;7`O)&-R8R1E>'0B.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["G5N;&EN:R`D
M9FEL96YA;64@:68@+64@)&9I;&5N86UE.PIP=7-H($!T;7!F:6QE+"`D9FEL
M96YA;64["GT*96QS92!["G)E='5R;B`H=6YD968L("1F:6QE;F%M92D@:68@
M*"UR("1F:6QE;F%M92D["GT*;W!E;B`D9F@L("<^)RP@)&9I;&5N86UE(&]R
M(&1I92`D(3L*8FEN;6]D92@D9F@I.PIR971U<FXH)&9H+"`D9FEL96YA;64I
M.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?
M4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2![
M"B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6
M>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0
M?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD
M97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D
M14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG
M>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G
M;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE
M)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T[
M"G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I
M9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@
M)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D
M:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]
M("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I
M+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#
M;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D
M<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P
M<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@
M(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F
M:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE
M9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D[
M"F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF
M:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?
M4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*
M:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX[
M"GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ
M=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%($%2
M1T,@05)'5E\P("D@*2!["F1E;&5T92`D14Y6>R=005)?)RXD7WT["GT*9F]R
M("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R=005)?
M)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6
M>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?8VQE86X@/2`B7U]%3E9?
M4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PII9B`H)$5.5GM005)?5$5-
M4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H(65X:7-T
M<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU92`]('-U8G-T
M<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%2
M7T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\[
M"GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I
M('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB
M.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.
M0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H
M"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP
M"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN
M.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87([
M"E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<2AP87(N<&PZ($-A;B=T
M(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O
M<B!D:7)E8W1O<GE<;BD*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N
M86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD
M*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D
M0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58
M251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U([
M"C$["E]?14Y$7U\*```!&P,[V````!H```#X<___]`````AX__\<#0``"'O_
M_Q@!```(H/__7`$``+B@___``0``.*'__^0!``!8H___9`(``+BD__\<`P``
M6*7__W@#```8IO__%`0``$BF__\\!```F*;__W0$``!8I___``4``&BG__\4
M!0``**G__Q`&``!8J?__)`8``$BJ__^$!@``"*S__[0&``!XK/__T`8``*BL
M___T!@``V*W__V0'```HNO__0`L``/B]___0#```:+[__UP-``"8OO__B`T`
M`/B^___4#0``%``````````!>E(``7P(`1L,!`2(`0``(````!P```#\<O__
M``0````."$8.#$H/"W0$>``_&CLJ,B0B0````$````#H>?__\R0```!!#@B%
M`D$.#(<#1`X0A@1!#A2#!48.H`8#W"0*#A1!PPX00<8.#$''#@A!Q0X$00L`
M``!@````A````*2>__^F`````$D."(4"00X,AP-!#A"&!$$.%(,%0PXP`D0.
M-$$..$$./$$.0$@.,%<*#A1#PPX00<8.#$''#@A!Q0X$10M:#A1%PPX00<8.
M#$''#@A!Q0X$````(````.@```#PGO__<@````!!#@B#`D4.(`)E"@X(0<,.
M!$$+?`````P!``!,G___&`(```!!#@B%`D$.#(<#0PX0A@1!#A2#!44.3%<.
M4$@.0%@.3$,.4$@.0`)+#DQ'#E!*#D`"=`H.%$'##A!!Q@X,0<<."$'%#@1'
M"P)0#DA!#DQ!#E!(#D!M#DQ+#E!(#D!.#D1!#DA)#DQ%#E!,#D````"T````
MC`$``.R@__]6`0```$$."(4"00X,AP-!#A"&!$$.%(,%2`Z@`6P*#A1!PPX0
M0<8.#$''#@A!Q0X$1`M##JP!00ZP`4@.H`%/#JP!00ZP`4@.H`%7#JP!1`ZP
M`60.K`%!#J@!00ZL`4$.L`%%#K0!0@ZX`4(.O`%!#L`!2`ZD`44.J`%!#JP!
M0@ZP`4@.H`%8#JP!00ZP`4@.H`%##JP!00ZP`4@.H`%V#JP!00ZP`5`.H`$`
M6````$0"``"4H?__D0````!!#@B#`D4.'$8.($@.%$8.&$$.'$(.($@.$$<*
M#@A#PPX$00M##AQ&#B!.#A!/#AQ&#B!.#A!/#AA"#AQ!#B!(#A!(#@A$PPX$
M``"8````H`(``-BA__^[`````$$."(4"00X,AP-##A"&!$$.%(,%2`ZT(%0.
MN"!%#KP@10[`($@.L"!3#K0@00ZX($(.O"!!#L`@2`ZP($<.O"!&#L`@1@[$
M($$.R"!!#LP@00[0($@.L"!6"@X40<,.$$'&#@Q!QPX(0<4.!$4+2PZ\($8.
MP"!(#K0@00ZX($$.O"!!#L`@2`ZP(``D````/`,``/RA__\G`````$,.'$8.
M($H.)$4.*$4.+$$.,$@.!```-````&0#```$HO__1`````!##AQ&#B!.#AQ&
M#B!&#AQ!#AA"#AQ%#B!%#B1%#BA%#BQ!#C!(#@2(````G`,``!RB__^Q````
M`$$."(<"00X,A@-!#A"#!$8.H$!7#JA`10ZL0$$.L$!%#K1`10ZX0$(.O$!%
M#L!`2`Z@0$<.I$!%#JA`2`ZL0$$.L$!(#J!`3`ZL0$$.L$!(#J!`20ZD0$$.
MJ$!!#JQ`00ZP0$P.H$!8"@X00<,.#$'&#@A!QPX$1`L``!`````H!```4*+_
M_P4`````````^````#P$``!,HO__N`$```!!#@B%`D$.#(<#00X0A@1!#A2#
M!48.P"!N#L@@1`[,($$.T"!(#L`@;`H.%$'##A!!Q@X,0<<."$'%#@1!"T,.
MS"!!#M`@1@[,($$.R"!)#LP@00[0($@.P"!L#L@@00[,($$.T"!(#L`@2P[,
M($$.T"!(#L`@;`[$($$.R"!%#LP@00[0($4.U"!%#M@@0@[<($$.X"!(#LP@
M1@[0($@.Q"!&#L@@00[,($(.T"!(#L`@1P[,($8.T"!.#L`@3P[(($4.S"!"
M#M`@2`[`($H.R"!"#LP@00[0($@.P"!3#LP@00[0($@.P"``$````#@%```0
MH___(@````````!<````3`4``"RC___G`````$$."(,"0PX@5@XL00XP3`X@
M;`XL0@XP2`X@3PH."$'##@1#"V`*#@A!PPX$3PMA#B1!#BA!#BQ%#C!(#B!(
M"@X(0<,.!$<+0PX(0\,.!``L````K`4``+RC__^W`0```$$."(<"00X,A@-#
M#D`#6P$*#@Q!Q@X(0<<.!$8+```8````W`4``$RE__]I`````$,.(&8*#@1'
M"P``(````/@%``"@I?__)`````!##A!(#AQ!#B!(#A!)"@X$0PL`;````!P&
M``"LI?__)@$```!!#@B%`D$.#(<#1@X0A@1!#A2#!4@.8`)2#FA!#FQ!#G!,
M#F`"0@H.%$'##A!!Q@X,0<<."$'%#@1)"T,.;$$.<&P.9$4.:$4.;$$.<$4.
M=$(.>$(.?$$.@`%,#F```-@#``",!@``;*;__T$,````00X(A0)!#@R'`T$.
M$(8$00X4@P5&#L""`@*G#LR"`D$.T(("3`[`@@)##LR"`D$.T(("2`[`@@)4
M#LR"`D0.T(("10[4@@)"#MB"`D(.W(("00[@@@)+#L""`@)##LR"`D$.T(("
M2`[`@@("0P[,@@)!#M""`D@.P(("5@[,@@)##M""`D@.P(("=0[,@@)*#M""
M`DH.U(("1P[8@@)%#MR"`D$.X(("10[D@@)"#NB"`D(.[(("00[P@@)(#LB"
M`D4.S(("00[0@@)(#L""`D@.S(("1@[0@@)(#L2"`D8.R(("1`[,@@)"#M""
M`D@.P(("1P[,@@)$#M""`D8.U(("10[8@@)"#MR"`D8.X(("2`[`@@)<"@X4
M0<,.$$'&#@Q!QPX(0<4.!$H+4PH.R(("00[,@@)$#M""`D8.U(("10[8@@)%
M"T,.S(("1@[0@@).#L""`E,.S(("1@[0@@)3#L""`DL.S(("1@[0@@).#L""
M`E,.S(("00[0@@)8#L""`DL.S(("00[0@@)&#LR"`D$.R(("00[,@@)&#M""
M`D@.P(("30[,@@)!#M""`D@.P(("?@[(@@)"#LR"`D$.T(("3`[`@@)C#L2"
M`D$.R(("10[,@@)%#M""`D4.U(("0@[8@@)"#MR"`D$.X(("2`[`@@):#LR"
M`D4.T(("00[4@@)!#MB"`D4.W(("00[@@@)%#N2"`D(.Z(("0@[L@@)!#O""
M`D@.P(("0P[(@@)%#LR"`D$.T(("2`[`@@)(#LR"`D0.T(("7`[`@@).#LR"
M`D$.T(("6`[`@@)T#LR"`D$.T(("2`[`@@)L#L2"`D(.R(("0@[,@@)%#M""
M`D@.Q(("0@[(@@)(#LR"`D$.T(("2`[`@@):#L2"`D(.R(("0@[,@@)$#M""
M`@*A#L""`D\.Q(("10[(@@)(#LR"`D0.T(("2`[`@@("H0[$@@)##LB"`D@.
MS(("00[0@@)8#L""`@+Z#L2"`D$.R(("00[,@@)(#M""`D\.P(("?`[,@@)$
M#M""`@)`#L""`@,%`@[,@@)$#M""`D4.U(("0@[8@@)"#MR"`D$.X(("2P[`
M@@)1#L2"`D@.R(("10[,@@)$#M""`D4.U(("0@[8@@)"#MR"`D$.X(("2`[`
M@@)7#LR"`D$.T(("3`[`@@("X0[$@@)"#LB"`D(.S(("10[0@@)(#L2"`D(.
MR(("2`[,@@)!#M""`DH.U(("2`[8@@)%#MR"`D0.X(("10[D@@)"#NB"`D(.
M[(("00[P@@)(#L""`@",`0``:`H``."N___.`P```$$."(4"00X,AP-!#A"&
M!$$.%(,%0PX\4@Y`6@XP50X\1@Y`1PY$0@Y(10Y,00Y02`XP<0XX00X\2`Y`
M2`XP5@X\1@Y`1PY$00Y(00Y,00Y02`XP6`X\1@Y`1PY$0@Y(00Y,00Y02`XP
M70X\1@Y`1PY$0@Y(10Y,00Y02`XP3`X\2`Y`2`XT10XX00X\00Y`2PXP3PX\
M1@Y`1PY$0@Y(10Y,00Y02`XP9`X\2`Y`2`XT00XX00X\00Y`2`XP0PX\1@Y`
M6@XP4@XX10X\00Y`2PXP8@H.%$'##A!!Q@X,0<<."$'%#@1+"U,./$8.0$D.
M/$$..$$./$$.0$@.,&8./$8.0$@.,'$..$$./$$.0$T.,%4*#C1!#CA'#CQ%
M#D!-"T@./$T.0%$.,$@./$8.0$<.1$(.2$$.3$$.4$@.,$4./$8.0$<.1$(.
M2$$.3$$.4$@.,$@./$8.0$8./$$..$$./$$.0$@.,$@*#CQ%#D!%"T8.-$8.
M.$(./$4.0```2````/@+```@L?__:0````!!#@B&`D$.#(,#0PX<10X@2PX0
M<`X810X<00X@2`X01PH.#$'##@A!Q@X$00M##@Q#PPX(0<8.!````#P```!$
M#```Y&K__PH"````1`P!`$<0!0)U`$4/`W5T!A`&`G5\$`,"=7@#BP$*P0P!
M`$'#0<9!Q4,,!`1!"P`H````A`P```2Q__\K`````$$."(,"3@X01@X41`X8
M1`X<1`X@2`X(0<,.!$@```"P#```"+'__UT`````00X(A0)!#@R'`T,.$(8$
M00X4@P5.#B!G#B1$#BA$#BQ!#C!-#B!'#A1!PPX00<8.#$''#@A!Q0X$```0
M````_`P``!RQ__\"````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#`F`0(H)@$"``````!`````0````$```#3`0``
M`0```"("```,````N)$$"`T```#DW`0(&0```/@^!0@;````!````!H```#\
M/@4('`````0```#U_O]OK($$"`4```!DB00(!@````2#!`@*````SP0```L`
M```0````%0`````````#`````$`%"`(```#X`0``%````!$````7````P(\$
M"!$```"0CP0($@```#`````3````"````/[__V\`CP0(____;P(```#P__]O
M-(X$"```````````````````````````````````````````````````````
M```````````````$/P4(``````````#VD00(!I($"!:2!`@FD@0(-I($"$:2
M!`A6D@0(9I($"':2!`B&D@0(EI($"*:2!`BVD@0(QI($"-:2!`CFD@0(]I($
M"`:3!`@6DP0()I,$"#:3!`A&DP0(5I,$"&:3!`AVDP0(AI,$"):3!`BFDP0(
MMI,$",:3!`C6DP0(YI,$"/:3!`@&E`0(%I0$"":4!`@VE`0(1I0$"%:4!`AF
ME`0(=I0$"(:4!`B6E`0(II0$"+:4!`C&E`0(UI0$".:4!`CVE`0(!I4$"!:5
M!`@FE00(-I4$"$:5!`A6E00(9I4$"':5!`B&E00(EI4$"*:5!`BVE00(QI4$
M"-:5!`@``````````/____\TX`0(1T-#.B`H56)U;G1U(#4N,RXQ+39U8G5N
M='4Q*2`U+C,N,2`R,#$V,#$Q-`!'0T,Z("A58G5N='4@-"XY+C,M.'5B=6YT
M=3(I(#0N.2XS```N<VAS=')T86(`+FEN=&5R<``N;F]T92Y!0DDM=&%G`"YN
M;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG
M;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L+F1Y;@`N<F5L+G!L=``N
M:6YI=``N<&QT+F=O=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H
M9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YJ8W(`+F1Y
M;F%M:6,`+F=O="YP;'0`+F1A=&$`+F)S<P`N8V]M;65N=```````````````
M````````````````````````````````````````````"P````$````"````
M5($$"%0!```3```````````````!`````````!,````'`````@```&B!!`AH
M`0``(```````````````!``````````A````!P````(```"(@00(B`$``"0`
M``````````````0`````````-````/;__V\"````K($$"*P!``!8`0``!0``
M```````$````!````#X````+`````@````2#!`@$`P``8`8```8````!````
M!````!````!&`````P````(```!DB00(9`D``,\$``````````````$`````
M````3@```/___V\"````-(X$"#0.``#,````!0`````````"`````@```%L`
M``#^__]O`@````"/!`@`#P``D`````8````"````!`````````!J````"0``
M``(```"0CP0(D`\``#`````%``````````0````(````<P````D```!"````
MP(\$",`/``#X`0``!0```!@````$````"````'P````!````!@```+B1!`BX
M$0``(P``````````````!`````````!W`````0````8```#@D00(X!$````$
M`````````````!`````$````@@````$````&````X)4$".`5```(````````
M```````(`````````(L````!````!@```/"5!`CP%0``\D8`````````````
M$`````````"1`````0````8```#DW`0(Y%P``!0```````````````0`````
M````EP````$````"````^-P$"/A<``#P0``````````````$`````````)\`
M```!`````@```.@=!0CHG0``W```````````````!`````````"M`````0``
M``(```#$'@4(Q)X``!`-``````````````0`````````MP````X````#````
M^#X%"/BN```$```````````````$`````````,,````/`````P```/P^!0C\
MK@``!```````````````!`````````#/`````0````,`````/P4(`*\```0`
M``````````````0`````````U`````8````#````!#\%"`2O``#X````!@``
M```````$````"````(8````!`````P```/P_!0C\KP``!```````````````
M!`````0```#=`````0````,`````0`4(`+````@!``````````````0````$
M````Y@````$````#````"$$%"`BQ```0```````````````$`````````.P`
M```(`````P```"!!!0@8L0``5!``````````````(`````````#Q`````0``
M`#``````````&+$``$\```````````````$````!`````0````,`````````
<`````&>Q``#Z```````````````!````````````
